# pftk documentation notes

## Jekyll requires Ruby

/usr/bin/ruby -e "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/master/install)"
brew install ruby
gem install bundler jekyll

## Start Jekyll Directory


